@@ -4,7 +4,7 @@ import math
 import matplotlib
 import matplotlib.pyplot as plt
 import PIL
-import numpy as np
+import numpy
 
 '''def X():
     def work(img):
@@ -32,14 +32,14 @@ def Rectangle(x_min, y_min, x_max, y_max):
     return work
 
 def __get_shift1_matrix(img_size):
-    return np.array([ #shifts (0, 0) from left upper corner to the center of image
+    return numpy.array([ #shifts (0, 0) from left upper corner to the center of image
         [1, 0, img_size[0] * 0.5],
         [0, 1, img_size[1] * 0.5],
         [0, 0, 1]
     ])
 
 def __get_shift2_matrix(img_size):
-    return np.array([ #shifts (0, 0) from center to the left upper corner of image
+    return numpy.array([ #shifts (0, 0) from center to the left upper corner of image
         [1, 0, -img_size[0] * 0.5],
         [0, 1, -img_size[1] * 0.5],
         [0, 0, 1]
@@ -49,7 +49,7 @@ def Affine(matrix_part):
     def work(img):
         nonlocal matrix_part
         size = img.size
-        matrix = np.array([
+        matrix = numpy.array([
             matrix_part[0],
             matrix_part[1],
             [0, 0, 1]
@@ -64,7 +64,7 @@ def Affine(matrix_part):
 
 def Shear_x(coef):
     return Affine(
-        np.array([
+        numpy.array([
             [1, coef, 0],
             [0, 1, 0]
         ])
@@ -72,7 +72,7 @@ def Shear_x(coef):
 
 def Shear_y(coef):
     return Affine(
-        np.array([
+        numpy.array([
             [1, 0, 0],
             [coef, 1, 0]
         ])
@@ -80,7 +80,7 @@ def Shear_y(coef):
 
 def Scale_x(factor):
     return Affine(
-        np.array([
+        numpy.array([
             [1.0 / factor, 0, 0],
             [0, 1, 0]
         ])
@@ -88,7 +88,7 @@ def Scale_x(factor):
 
 def Scale_y(factor):
     return Affine(
-        np.array([
+        numpy.array([
             [1, 0, 0],
             [0, 1.0 / factor, 0]
         ])
@@ -96,7 +96,7 @@ def Scale_y(factor):
 
 def Scale(factor):
     return Affine(
-        np.array([
+        numpy.array([
             [1.0 / factor, 0, 0],
             [0, 1.0 / factor, 0]
         ])
@@ -104,7 +104,7 @@ def Scale(factor):
 
 def Rotate(angle):
     return Affine(
-        np.array([
+        numpy.array([
             [cos(angle), sin(angle), 0],
             [-sin(angle), cos(angle), 0]
         ])
@@ -170,8 +170,8 @@ def Deform(grid_size, distortion):
                 raise "distortion should be between 0 and 0.5"
             if (steps < 1 or steps > 10):
                 raise "steps should be between 1 and 10"
-            points = np.zeros((steps + 1, steps + 1, 2), dtype = int)
-            points_deformed = np.copy(points)
+            points = numpy.zeros((steps + 1, steps + 1, 2), dtype = int)
+            points_deformed = numpy.copy(points)
             dx = round(img_size[0] / steps)
             dy = round(img_size[1] / steps)
             for step_x in range(steps + 1):
@@ -215,7 +215,7 @@ def np_to_pil(img):
     return PIL.Image.fromarray(img , 'L')
 
 def pil_to_np(img):
-    return np.reshape(np.asarray(img.getdata()), img.size)
+    return numpy.reshape(numpy.asarray(img.getdata()), img.size)
 
 def edit(img, *filters, scaling = 4, demo = False):
     '''def draw_grid(img, step, clear = False):
@@ -231,7 +231,7 @@ def edit(img, *filters, scaling = 4, demo = False):
         raise ValueError("scaling should be integer more or equal to 1")
     if (len(filters) == 0):
         raise ValueError("empty list of filters")
-    is_np = img.__class__ == np.ndarray
+    is_np = img.__class__ == numpy.ndarray
     is_pil = img.__class__ == PIL.Image.Image
     if is_np:
         img = np_to_pil(img)
